# ------------------------------------------------------------------------
#
#	genfilepath.pl
#
# Notes:
#   - generate all include,source and library files' path
#
#   Date			  Name		Vers		Change
#	----------	 ------		----	-------------------------------
#	2006-04-03    tanrw	   1.0   Init Version
# 2006-04-11		tanrw		 1.1	 Split all incs & srcs to several parts,
#																	 as arument list too long for shell command.
# ------------------------------------------------------------------------
use strict;
use warnings;
use File::Copy;
use File::Find;
use File::Basename;
use Cwd;

my $curpath;
my ($issrcfile,$isincfile,$islibfile);
my (@allcfgs,$allcfgs,$cfg);
my (@incfiles,@srcfiles,@libfiles);
my ($metammi, $metammistr)=@ARGV;

sub createdir
{
	my ($path) = @_;
	my ($tmpPath) = $path.'/../';
	
	if (not -d "$tmpPath")
	{
		createdir($tmpPath);
	}
	
	if (not -d "$path")
	{
		mkdir "$path" or die "$!";
	}
}


# ----------- Main ---------- 


#(@allcfgs) = @ARGV;

#get the current directory
$curpath = cwd;
$curpath =~s/\/Win32\/build//g; 

open(FH,"cfgfiles.txt")||die "$!\n";
while(<FH>)
{
	chomp;
	$allcfgs = $allcfgs.$_;
}
close(FH);
@allcfgs = split(/ /,$allcfgs);

foreach $cfg (@allcfgs)
{
	$cfg =~s/\.\.\/\.\./$curpath/g;
	$issrcfile = 0;
	$isincfile = 0;
	$islibfile = 0;
	open(FH,"$cfg")||die "$!\n";
	while(<FH>)
	{
		chomp;
		if(/\[SourceFiles\]/i)
		{
			$issrcfile = 1;
			$isincfile = 0;
			$islibfile = 0;
			next;
		}
		if(/\[IncludeFiles\]/i)
		{
			$isincfile = 1;
			$issrcfile = 0;
			$islibfile = 0;
			next;
		}
		if(/\[LinkFiles\]/i)
		{
			$islibfile = 1;
			$isincfile = 0;
			$issrcfile = 0;
			next;
		}
		if((/\[SourceFiles\_Options\]/i) or (/\[Modules\]/i))
		{
			$issrcfile = 0;
			$isincfile = 0;
			$islibfile = 0;
			next;
		}
		if(($issrcfile == 1) and (not /^$/) and (not /^#/))
		{
			push @srcfiles,$_;
    }
    if(($isincfile == 1) and (not /^$/) and (not /^#/))
    {
    	push @incfiles,$_;
    }
    if(($islibfile == 1) and (not /^$/) and (not /^#/))
    {
    	push @libfiles,$_;
    }
  }
  close(FH);
}

print "# include files\n";
if(@incfiles)
{
	foreach (@incfiles)
	{
		if(/^!/)
		{
			$_ = substr($_,1);
			print "\n";
			print "$_\n";
		}
		elsif((not /^$/) and (not /^#/))
		{
			if(/\/apps\//i)
			{
				print "META_APPS_INCS+=$_\n";
			}
			elsif(/\/common\//i)
			{
				print "META_COMMON_INCS+=$_\n";
			}
			elsif(/\/system\//i)
			{
				print "META_SYSTEM_INCS+=$_\n";
			}
			elsif(/\/UTK\//i)
			{
				print "META_UTK_INCS+=$_\n";
			}
			elsif(/\/3Parts\//i)
			{
				print "META_3PARTS_INCS+=$_\n";
			}
			else
			{
				print "META_INCS+=$_\n";
			}
		}
	}
}

print "# source files\n";
if(@srcfiles)
{
	foreach (@srcfiles)
	{
		my $Srcfilename = $_;
		
		if(/\.c/i or /\.cpp/i or /\.s/i)
		{
			$Srcfilename =~s/\$\($metammistr\)/$metammi/g;
			if (not -f $Srcfilename)
			{
				my $filename = basename($Srcfilename);
				my $dirname = $Srcfilename;

				$dirname =~s/$filename//g;
				
				createdir($dirname);
				open(SRCFH, ">$Srcfilename")||die "$!\n";
				close(SRCFH);
			}
		}
		
		if(/^!/)
		{
			$_ = substr($_,1);
			print "\n";
			print "$_\n";
		}
		elsif((not /^$/) and (not /^#/))
		{
			if(/\/apps\//i)
			{
				print "META_APPS_SRCS+=$_\n";
			} 
			elsif(/\/common\//i)
			{
				print "META_COMMON_SRCS+=$_\n";
			}
			elsif(/\/system\//i)
			{
				print "META_SYSTEM_SRCS+=$_\n";
			}
			elsif(/\/UTK\//i)
			{
				print "META_UTK_SRCS+=$_\n";
			}
			elsif(/\/3Parts\//i)
			{
				print "META_3PARTS_SRCS+=$_\n";
			}
			else
			{
				print "META_SRCS+=$_\n";
			}
		}
	}
}

print "# libarary files\n";
if(@libfiles)
{
	foreach (@libfiles)
	{
		if(/^!/)
		{
			$_ = substr($_,1);
			print "\n";
			print "$_\n";
		}
		elsif((not /^$/) and (not /^#/))
		{
				print "META_LIBS+=$_\n";
		}
	}
}

exit;
